{%  load static %}
<a href="#" data-jq-dropdown="#jq-dropdown-{{ dom_id }}">{{ label }}&nbsp;<span class="jq-dropdown-caret"></span></a>
<div id="jq-dropdown-{{ dom_id }}" class="jq-dropdown jq-dropdown-tip jq-dropdown-relative">
    <ul class="jq-dropdown-menu">
        {% for item in items %}
            {% if item.divided %}
                <li class="jq-dropdown-divider"></li>
            {% endif %}
            <li>
                {% if item.enabled %}
                    <a class="{{ item.classes }}" href="{{ item.url }}" title="{{ item.tooltip }}">{{ item.label }}</a>
                {% else %}
                    <span class="{{ item.classes }} jq-disabled" title="{{ item.tooltip }}">{{ item.label }}</span>
                {% endif %}
            </li>
        {% endfor %}
    </ul>
</div>